==> colourvalues_0.3.0.tar.gz: colourvalues/inst/include/colourvalues/palettes/matlab_like.hpp <==
#ifndef R_COLOURVALUES_MATLAB_LIKE_H
#define R_COLOURVALUES_MATLAB_LIKE_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector matlab_like_red = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0.0117647058823529,0.0196078431372549,0.0313725490196078,
    0.0431372549019608,0.0509803921568627,0.0627450980392157,0.0745098039215686,
    0.0823529411764706,0.0941176470588235,0.105882352941176,0.117647058823529,
    0.125490196078431,0.137254901960784,0.149019607843137,0.156862745098039,
    0.168627450980392,0.180392156862745,0.188235294117647,0.2,
    0.211764705882353,0.219607843137255,0.231372549019608,0.243137254901961,
    0.250980392156863,0.262745098039216,0.274509803921569,0.282352941176471,
    0.294117647058824,0.305882352941176,0.317647058823529,0.325490196078431,
    0.337254901960784,0.349019607843137,0.356862745098039,0.368627450980392,
    0.380392156862745,0.388235294117647,0.4,0.411764705882353,
    0.419607843137255,0.431372549019608,0.443137254901961,0.450980392156863,
    0.462745098039216,0.474509803921569,0.482352941176471,0.494117647058824,
    0.505882352941176,0.517647058823529,0.525490196078431,0.537254901960784,
    0.549019607843137,0.556862745098039,0.568627450980392,0.580392156862745,
    0.588235294117647,0.6,0.611764705882353,0.619607843137255,
    0.631372549019608,0.643137254901961,0.650980392156863,0.662745098039216,
    0.674509803921569,0.682352941176471,0.694117647058824,0.705882352941177,
    0.717647058823529,0.725490196078431,0.737254901960784,0.749019607843137,
    0.756862745098039,0.768627450980392,0.780392156862745,0.788235294117647,
    0.8,0.811764705882353,0.819607843137255,0.831372549019608,
    0.843137254901961,0.850980392156863,0.862745098039216,0.874509803921569,
    0.882352941176471,0.894117647058824,0.905882352941176,0.917647058823529,
    0.925490196078431,0.937254901960784,0.949019607843137,0.956862745098039,
    0.968627450980392,0.980392156862745,0.988235294117647,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    0.988235294117647,0.980392156862745,0.968627450980392,0.956862745098039,
    0.949019607843137,0.937254901960784,0.925490196078431,0.917647058823529,
    0.905882352941176,0.894117647058824,0.886274509803922,0.874509803921569,
    0.862745098039216,0.854901960784314,0.843137254901961,0.835294117647059,
    0.823529411764706,0.811764705882353,0.803921568627451,0.792156862745098,
    0.780392156862745,0.772549019607843,0.76078431372549,0.749019607843137,
    0.741176470588235,0.729411764705882,0.717647058823529,0.709803921568627,
    0.698039215686274,0.686274509803922,0.67843137254902,0.666666666666667
  };

  const Rcpp::NumericVector matlab_like_green = {
    0,0.0117647058823529,0.0196078431372549,0.0313725490196078,
    0.0431372549019608,0.0509803921568627,0.0627450980392157,0.0745098039215686,
    0.0823529411764706,0.0941176470588235,0.105882352941176,0.113725490196078,
    0.125490196078431,0.137254901960784,0.145098039215686,0.156862745098039,
    0.168627450980392,0.176470588235294,0.188235294117647,0.196078431372549,
    0.207843137254902,0.219607843137255,0.227450980392157,0.23921568627451,
    0.250980392156863,0.258823529411765,0.270588235294118,0.282352941176471,
    0.290196078431373,0.301960784313725,0.313725490196078,0.32156862745098,
    0.333333333333333,0.345098039215686,0.352941176470588,0.364705882352941,
    0.376470588235294,0.384313725490196,0.396078431372549,0.407843137254902,
    0.415686274509804,0.427450980392157,0.43921568627451,0.447058823529412,
    0.458823529411765,0.470588235294118,0.47843137254902,0.490196078431373,
    0.501960784313725,0.509803921568627,0.52156862745098,0.529411764705882,
    0.541176470588235,0.552941176470588,0.56078431372549,0.572549019607843,
    0.584313725490196,0.592156862745098,0.603921568627451,0.615686274509804,
    0.623529411764706,0.635294117647059,0.647058823529412,0.654901960784314,
    0.666666666666667,0.67843137254902,0.686274509803922,0.698039215686274,
    0.709803921568627,0.717647058823529,0.729411764705882,0.741176470588235,
    0.749019607843137,0.76078431372549,0.772549019607843,0.780392156862745,
    0.792156862745098,0.803921568627451,0.811764705882353,0.823529411764706,
    0.831372549019608,0.843137254901961,0.854901960784314,0.862745098039216,
    0.874509803921569,0.886274509803922,0.894117647058824,0.905882352941176,
    0.917647058823529,0.925490196078431,0.937254901960784,0.949019607843137,
    0.956862745098039,0.968627450980392,0.980392156862745,0.988235294117647,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    0.988235294117647,0.980392156862745,0.968627450980392,0.956862745098039,
    0.949019607843137,0.937254901960784,0.925490196078431,0.917647058823529,
    0.905882352941176,0.894117647058824,0.886274509803922,0.874509803921569,
    0.862745098039216,0.854901960784314,0.843137254901961,0.835294117647059,
    0.823529411764706,0.811764705882353,0.803921568627451,0.792156862745098,
    0.780392156862745,0.772549019607843,0.76078431372549,0.749019607843137,
    0.741176470588235,0.729411764705882,0.717647058823529,0.709803921568627,
    0.698039215686274,0.686274509803922,0.67843137254902,0.666666666666667,
    0.654901960784314,0.647058823529412,0.635294117647059,0.623529411764706,
    0.615686274509804,0.603921568627451,0.592156862745098,0.584313725490196,
    0.572549019607843,0.56078431372549,0.552941176470588,0.541176470588235,
    0.529411764705882,0.52156862745098,0.509803921568627,0.501960784313725,
    0.490196078431373,0.47843137254902,0.470588235294118,0.458823529411765,
    0.447058823529412,0.43921568627451,0.427450980392157,0.415686274509804,
    0.407843137254902,0.396078431372549,0.384313725490196,0.376470588235294,
    0.364705882352941,0.352941176470588,0.345098039215686,0.333333333333333,
    0.32156862745098,0.313725490196078,0.301960784313725,0.290196078431373,
    0.282352941176471,0.270588235294118,0.258823529411765,0.250980392156863,
    0.23921568627451,0.227450980392157,0.219607843137255,0.207843137254902,
    0.196078431372549,0.188235294117647,0.176470588235294,0.168627450980392,
    0.156862745098039,0.145098039215686,0.137254901960784,0.125490196078431,
    0.113725490196078,0.105882352941176,0.0941176470588235,0.0823529411764706,
    0.0745098039215686,0.0627450980392157,0.0509803921568627,0.0431372549019608,
    0.0313725490196078,0.0196078431372549,0.0117647058823529,0
  };

  const Rcpp::NumericVector matlab_like_blue = {
    0.666666666666667,0.67843137254902,0.686274509803922,0.698039215686274,
    0.709803921568627,0.717647058823529,0.729411764705882,0.741176470588235,
    0.749019607843137,0.76078431372549,0.772549019607843,0.780392156862745,
    0.792156862745098,0.803921568627451,0.811764705882353,0.823529411764706,
    0.831372549019608,0.843137254901961,0.854901960784314,0.862745098039216,
    0.874509803921569,0.886274509803922,0.894117647058824,0.905882352941176,
    0.917647058823529,0.925490196078431,0.937254901960784,0.949019607843137,
    0.956862745098039,0.968627450980392,0.980392156862745,0.988235294117647,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,0.988235294117647,0.980392156862745,0.968627450980392,
    0.956862745098039,0.949019607843137,0.937254901960784,0.925490196078431,
    0.917647058823529,0.905882352941176,0.894117647058824,0.882352941176471,
    0.874509803921569,0.862745098039216,0.850980392156863,0.843137254901961,
    0.831372549019608,0.819607843137255,0.811764705882353,0.8,
    0.788235294117647,0.780392156862745,0.768627450980392,0.756862745098039,
    0.749019607843137,0.737254901960784,0.725490196078431,0.717647058823529,
    0.705882352941177,0.694117647058824,0.682352941176471,0.674509803921569,
    0.662745098039216,0.650980392156863,0.643137254901961,0.631372549019608,
    0.619607843137255,0.611764705882353,0.6,0.588235294117647,
    0.580392156862745,0.568627450980392,0.556862745098039,0.549019607843137,
    0.537254901960784,0.525490196078431,0.517647058823529,0.505882352941176,
    0.494117647058824,0.482352941176471,0.474509803921569,0.462745098039216,
    0.450980392156863,0.443137254901961,0.431372549019608,0.419607843137255,
    0.411764705882353,0.4,0.388235294117647,0.380392156862745,
    0.368627450980392,0.356862745098039,0.349019607843137,0.337254901960784,
    0.325490196078431,0.317647058823529,0.305882352941176,0.294117647058824,
    0.282352941176471,0.274509803921569,0.262745098039216,0.250980392156863,
    0.243137254901961,0.231372549019608,0.219607843137255,0.211764705882353,
    0.2,0.188235294117647,0.180392156862745,0.168627450980392,
    0.156862745098039,0.149019607843137,0.137254901960784,0.125490196078431,
    0.117647058823529,0.105882352941176,0.0941176470588235,0.0823529411764706,
    0.0745098039215686,0.0627450980392157,0.0509803921568627,0.0431372549019608,
    0.0313725490196078,0.0196078431372549,0.0117647058823529,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

const Rcpp::List matlab_like = Rcpp::List::create(
  _["r"] = matlab_like_red,
  _["g"] = matlab_like_green,
  _["b"] = matlab_like_blue
);
} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/matlab_like.hpp <==
#ifndef R_COLOURVALUES_MATLAB_LIKE_H
#define R_COLOURVALUES_MATLAB_LIKE_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector matlab_like_red = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0.0117647058823529,0.0196078431372549,0.0313725490196078,
    0.0431372549019608,0.0509803921568627,0.0627450980392157,0.0745098039215686,
    0.0823529411764706,0.0941176470588235,0.105882352941176,0.117647058823529,
    0.125490196078431,0.137254901960784,0.149019607843137,0.156862745098039,
    0.168627450980392,0.180392156862745,0.188235294117647,0.2,
    0.211764705882353,0.219607843137255,0.231372549019608,0.243137254901961,
    0.250980392156863,0.262745098039216,0.274509803921569,0.282352941176471,
    0.294117647058824,0.305882352941176,0.317647058823529,0.325490196078431,
    0.337254901960784,0.349019607843137,0.356862745098039,0.368627450980392,
    0.380392156862745,0.388235294117647,0.4,0.411764705882353,
    0.419607843137255,0.431372549019608,0.443137254901961,0.450980392156863,
    0.462745098039216,0.474509803921569,0.482352941176471,0.494117647058824,
    0.505882352941176,0.517647058823529,0.525490196078431,0.537254901960784,
    0.549019607843137,0.556862745098039,0.568627450980392,0.580392156862745,
    0.588235294117647,0.6,0.611764705882353,0.619607843137255,
    0.631372549019608,0.643137254901961,0.650980392156863,0.662745098039216,
    0.674509803921569,0.682352941176471,0.694117647058824,0.705882352941177,
    0.717647058823529,0.725490196078431,0.737254901960784,0.749019607843137,
    0.756862745098039,0.768627450980392,0.780392156862745,0.788235294117647,
    0.8,0.811764705882353,0.819607843137255,0.831372549019608,
    0.843137254901961,0.850980392156863,0.862745098039216,0.874509803921569,
    0.882352941176471,0.894117647058824,0.905882352941176,0.917647058823529,
    0.925490196078431,0.937254901960784,0.949019607843137,0.956862745098039,
    0.968627450980392,0.980392156862745,0.988235294117647,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    0.988235294117647,0.980392156862745,0.968627450980392,0.956862745098039,
    0.949019607843137,0.937254901960784,0.925490196078431,0.917647058823529,
    0.905882352941176,0.894117647058824,0.886274509803922,0.874509803921569,
    0.862745098039216,0.854901960784314,0.843137254901961,0.835294117647059,
    0.823529411764706,0.811764705882353,0.803921568627451,0.792156862745098,
    0.780392156862745,0.772549019607843,0.76078431372549,0.749019607843137,
    0.741176470588235,0.729411764705882,0.717647058823529,0.709803921568627,
    0.698039215686274,0.686274509803922,0.67843137254902,0.666666666666667
  };

  const Rcpp::NumericVector matlab_like_green = {
    0,0.0117647058823529,0.0196078431372549,0.0313725490196078,
    0.0431372549019608,0.0509803921568627,0.0627450980392157,0.0745098039215686,
    0.0823529411764706,0.0941176470588235,0.105882352941176,0.113725490196078,
    0.125490196078431,0.137254901960784,0.145098039215686,0.156862745098039,
    0.168627450980392,0.176470588235294,0.188235294117647,0.196078431372549,
    0.207843137254902,0.219607843137255,0.227450980392157,0.23921568627451,
    0.250980392156863,0.258823529411765,0.270588235294118,0.282352941176471,
    0.290196078431373,0.301960784313725,0.313725490196078,0.32156862745098,
    0.333333333333333,0.345098039215686,0.352941176470588,0.364705882352941,
    0.376470588235294,0.384313725490196,0.396078431372549,0.407843137254902,
    0.415686274509804,0.427450980392157,0.43921568627451,0.447058823529412,
    0.458823529411765,0.470588235294118,0.47843137254902,0.490196078431373,
    0.501960784313725,0.509803921568627,0.52156862745098,0.529411764705882,
    0.541176470588235,0.552941176470588,0.56078431372549,0.572549019607843,
    0.584313725490196,0.592156862745098,0.603921568627451,0.615686274509804,
    0.623529411764706,0.635294117647059,0.647058823529412,0.654901960784314,
    0.666666666666667,0.67843137254902,0.686274509803922,0.698039215686274,
    0.709803921568627,0.717647058823529,0.729411764705882,0.741176470588235,
    0.749019607843137,0.76078431372549,0.772549019607843,0.780392156862745,
    0.792156862745098,0.803921568627451,0.811764705882353,0.823529411764706,
    0.831372549019608,0.843137254901961,0.854901960784314,0.862745098039216,
    0.874509803921569,0.886274509803922,0.894117647058824,0.905882352941176,
    0.917647058823529,0.925490196078431,0.937254901960784,0.949019607843137,
    0.956862745098039,0.968627450980392,0.980392156862745,0.988235294117647,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    0.988235294117647,0.980392156862745,0.968627450980392,0.956862745098039,
    0.949019607843137,0.937254901960784,0.925490196078431,0.917647058823529,
    0.905882352941176,0.894117647058824,0.886274509803922,0.874509803921569,
    0.862745098039216,0.854901960784314,0.843137254901961,0.835294117647059,
    0.823529411764706,0.811764705882353,0.803921568627451,0.792156862745098,
    0.780392156862745,0.772549019607843,0.76078431372549,0.749019607843137,
    0.741176470588235,0.729411764705882,0.717647058823529,0.709803921568627,
    0.698039215686274,0.686274509803922,0.67843137254902,0.666666666666667,
    0.654901960784314,0.647058823529412,0.635294117647059,0.623529411764706,
    0.615686274509804,0.603921568627451,0.592156862745098,0.584313725490196,
    0.572549019607843,0.56078431372549,0.552941176470588,0.541176470588235,
    0.529411764705882,0.52156862745098,0.509803921568627,0.501960784313725,
    0.490196078431373,0.47843137254902,0.470588235294118,0.458823529411765,
    0.447058823529412,0.43921568627451,0.427450980392157,0.415686274509804,
    0.407843137254902,0.396078431372549,0.384313725490196,0.376470588235294,
    0.364705882352941,0.352941176470588,0.345098039215686,0.333333333333333,
    0.32156862745098,0.313725490196078,0.301960784313725,0.290196078431373,
    0.282352941176471,0.270588235294118,0.258823529411765,0.250980392156863,
    0.23921568627451,0.227450980392157,0.219607843137255,0.207843137254902,
    0.196078431372549,0.188235294117647,0.176470588235294,0.168627450980392,
    0.156862745098039,0.145098039215686,0.137254901960784,0.125490196078431,
    0.113725490196078,0.105882352941176,0.0941176470588235,0.0823529411764706,
    0.0745098039215686,0.0627450980392157,0.0509803921568627,0.0431372549019608,
    0.0313725490196078,0.0196078431372549,0.0117647058823529,0
  };

  const Rcpp::NumericVector matlab_like_blue = {
    0.666666666666667,0.67843137254902,0.686274509803922,0.698039215686274,
    0.709803921568627,0.717647058823529,0.729411764705882,0.741176470588235,
    0.749019607843137,0.76078431372549,0.772549019607843,0.780392156862745,
    0.792156862745098,0.803921568627451,0.811764705882353,0.823529411764706,
    0.831372549019608,0.843137254901961,0.854901960784314,0.862745098039216,
    0.874509803921569,0.886274509803922,0.894117647058824,0.905882352941176,
    0.917647058823529,0.925490196078431,0.937254901960784,0.949019607843137,
    0.956862745098039,0.968627450980392,0.980392156862745,0.988235294117647,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,0.988235294117647,0.980392156862745,0.968627450980392,
    0.956862745098039,0.949019607843137,0.937254901960784,0.925490196078431,
    0.917647058823529,0.905882352941176,0.894117647058824,0.882352941176471,
    0.874509803921569,0.862745098039216,0.850980392156863,0.843137254901961,
    0.831372549019608,0.819607843137255,0.811764705882353,0.8,
    0.788235294117647,0.780392156862745,0.768627450980392,0.756862745098039,
    0.749019607843137,0.737254901960784,0.725490196078431,0.717647058823529,
    0.705882352941177,0.694117647058824,0.682352941176471,0.674509803921569,
    0.662745098039216,0.650980392156863,0.643137254901961,0.631372549019608,
    0.619607843137255,0.611764705882353,0.6,0.588235294117647,
    0.580392156862745,0.568627450980392,0.556862745098039,0.549019607843137,
    0.537254901960784,0.525490196078431,0.517647058823529,0.505882352941176,
    0.494117647058824,0.482352941176471,0.474509803921569,0.462745098039216,
    0.450980392156863,0.443137254901961,0.431372549019608,0.419607843137255,
    0.411764705882353,0.4,0.388235294117647,0.380392156862745,
    0.368627450980392,0.356862745098039,0.349019607843137,0.337254901960784,
    0.325490196078431,0.317647058823529,0.305882352941176,0.294117647058824,
    0.282352941176471,0.274509803921569,0.262745098039216,0.250980392156863,
    0.243137254901961,0.231372549019608,0.219607843137255,0.211764705882353,
    0.2,0.188235294117647,0.180392156862745,0.168627450980392,
    0.156862745098039,0.149019607843137,0.137254901960784,0.125490196078431,
    0.117647058823529,0.105882352941176,0.0941176470588235,0.0823529411764706,
    0.0745098039215686,0.0627450980392157,0.0509803921568627,0.0431372549019608,
    0.0313725490196078,0.0196078431372549,0.0117647058823529,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  // const Rcpp::List matlab_like = Rcpp::List::create(
  //   _["r"] = matlab_like_red,
  //   _["g"] = matlab_like_green,
  //   _["b"] = matlab_like_blue
  // );
} // namespace palette
} // namepsace colourvalues

#endif
